(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     32257,        841]
NotebookOptionsPosition[     30123,        800]
NotebookOutlinePosition[     30530,        816]
CellTagsIndexPosition[     30487,        813]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Modified Gravitational Potential", "Title",
 CellChangeTimes->{{3.860148700332677*^9, 
  3.860148711839694*^9}},ExpressionUUID->"f69b802f-5044-468f-a8e1-\
9bef7a8902d6"],

Cell["Marvin Zanke & Leon von Detten", "Author",
 CellChangeTimes->{{3.8601488220441227`*^9, 
  3.860148831084791*^9}},ExpressionUUID->"85b37274-23c3-405e-97cd-\
5b49c1c5812b"],

Cell["28.04.2022", "Date",
 CellChangeTimes->{{3.860148833138386*^9, 
  3.860148842158729*^9}},ExpressionUUID->"d965cd49-3457-4bc8-8440-\
fa8d7a341ae9"],

Cell["\<\
In this notebook, we plot the various trajectories found in A1) of exercise \
sheet 3, with the exception of the solution a=0=b, which yields a circle and \
the only closed trajectory.\
\>", "Text",
 CellChangeTimes->{{3.860148761000677*^9, 3.8601488171806793`*^9}, {
  3.860152619712397*^9, 3.860152620980009*^9}, {3.8601570335274057`*^9, 
  3.86015705608706*^9}},ExpressionUUID->"dac38f0b-75c0-4933-b050-\
b9ced58d4b3a"],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.860148853743733*^9, 
  3.860148859338518*^9}},ExpressionUUID->"6132a769-c43c-4e83-a07d-\
0926f01d53cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Define", " ", "the", " ", "unit", " ", "vector", " ", 
      SubscriptBox[
       OverscriptBox["e", "\[RightVector]"], "r"], " ", "in", " ", 
      "spherical", " ", "coordinates", " ", "for", " ", "\[Theta]"}], "=", 
     RowBox[{
      RowBox[{"\[Pi]", "/", "2"}], " ", "fixed"}]}], ",", " ", 
    RowBox[{
     RowBox[{"which", " ", "fulfills", " ", 
      OverscriptBox["r", "\[RightVector]"], 
      RowBox[{"(", "\[Phi]", ")"}]}], "=", 
     RowBox[{"r", 
      RowBox[{"(", "\[Phi]", ")"}], 
      RowBox[{
       SubscriptBox[
        OverscriptBox["e", "\[RightVector]"], "r"], ".", " ", "Note"}], " ", 
      "that", " ", "the", " ", "third", " ", "component", " ", "vanishes", 
      " ", "and", " ", "is", " ", "thus", " ", "discarded", " ", "here", " ", 
      "to", " ", "enforce", " ", "a", " ", "2", "D", " ", 
      RowBox[{"plot", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"er", "=", 
    RowBox[{"(", GridBox[{
       {
        RowBox[{"Cos", "[", "\[Phi]", "]"}]},
       {
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}
      }], ")"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8601499062424583`*^9, 3.8601499445041227`*^9}, {
  3.8601503004442873`*^9, 3.8601503007733097`*^9}, {3.860151495945826*^9, 
  3.860151520728366*^9}, {3.860151614143264*^9, 3.8601516146698503`*^9}, {
  3.860151662654971*^9, 3.860151685620323*^9}, {3.860152635849346*^9, 
  3.860152645700775*^9}, {3.860153322868733*^9, 3.860153323351252*^9}, {
  3.860153362558084*^9, 3.860153362805787*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"d35989f3-8a4a-4ddf-981a-bfdecfada5d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Define", " ", "the", " ", "constants", " ", "a", " ", "and", " ", "b"}], 
    ",", " ", 
    RowBox[{
    "which", " ", "we", " ", "will", " ", "use", " ", "as", " ", 
     "abbreviations", " ", "in", " ", "our", " ", 
     RowBox[{"formulae", ".", " ", "We"}], " ", "denote", " ", "the", " ", 
     "energy", " ", "by", " ", "\"\<En\>\"", " ", "instead", " ", "of", " ", 
     "\"\<E\>\"", " ", "because", " ", "\"\<E\>\"", " ", "is", " ", 
     "reserved", " ", "for", " ", 
     RowBox[{"Euler", "'"}], "s", " ", "number", " ", "in", " ", 
     RowBox[{"Mathematica", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"a", "[", 
      RowBox[{"m_", ",", "En_"}], "]"}], ":=", 
     FractionBox[
      RowBox[{"2", "En"}], "m"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{"m_", ",", "\[Gamma]_", ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      FractionBox[
       SuperscriptBox["Lz", "2"], 
       SuperscriptBox["m", "2"]], "-", 
      FractionBox[
       RowBox[{"2", "\[Gamma]"}], "m"]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8601489824799356`*^9, 3.860149094621849*^9}, {
   3.860149388908124*^9, 3.860149426772297*^9}, {3.8601499576820707`*^9, 
   3.8601499859310303`*^9}, {3.860150719609222*^9, 3.860150725813142*^9}, {
   3.860151541824285*^9, 3.860151542483309*^9}, {3.8601516510742683`*^9, 
   3.860151655270564*^9}, 3.860151697211933*^9},
 CellLabel->"In[2]:=",ExpressionUUID->"d906d344-0a21-4b9c-8407-786ac56c3bfd"],

Cell[TextData[{
 "Define the (magnitudes of the) trajectories r(t) and r(\[Phi]) obtained \
from the equation of motion \[LongDash] the latter for the cases\n1) En>0, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["Lz", "2"], ">", 
    RowBox[{"2", "\[Gamma]m"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "4de40505-8def-495b-a0b7-c3871df8317a"],
 ",\n2) En>0, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["Lz", "2"], "<", 
    RowBox[{"2", "\[Gamma]m"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c7aa3cb1-630b-4206-830c-d403eaffedcf"],
 ",\n3) En<0, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["Lz", "2"], "<", 
    RowBox[{"2", "\[Gamma]m"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e5df29b1-971c-47c9-8f29-96c482269cac"],
 ",\n4) En<0, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["Lz", "2"], ">", 
    RowBox[{"2", "\[Gamma]m"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "28a21842-c6b7-459d-8abc-ea370e81b0ec"],
 ",\n5) En>0, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["Lz", "2"], "=", 
    RowBox[{"2", "\[Gamma]m"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "61d19246-8fca-4217-ba56-cc557cba5b5e"],
 ",\n6) En=0, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["Lz", "2"], "<", 
    RowBox[{"2", "\[Gamma]m"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "0013f4c4-6f66-49c5-84a4-704d83747626"],
 "."
}], "Text",
 CellChangeTimes->{{3.860150747491111*^9, 3.8601508767021923`*^9}, 
   3.860151003599022*^9, {3.860151292968109*^9, 3.860151315228553*^9}, {
   3.860151408332285*^9, 3.860151454697832*^9}, {3.860152946697111*^9, 
   3.8601529565906057`*^9}, {3.860173293537781*^9, 
   3.860173301643653*^9}},ExpressionUUID->"70e003b5-3a8c-4787-8a67-\
a287fe8028f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"r", 
    RowBox[{
     RowBox[{"(", "t", ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rt", "[", 
      RowBox[{
      "t_", ",", "t0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", ",", "Lz_"}],
       "]"}], ":=", 
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"a", "[", 
         RowBox[{"m", ",", "En"}], "]"}], "*", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"t", "-", "t0"}], ")"}], "2"]}], "+", 
       FractionBox[
        RowBox[{"b", "[", 
         RowBox[{"m", ",", "\[Gamma]", ",", "Lz"}], "]"}], 
        RowBox[{"a", "[", 
         RowBox[{"m", ",", "En"}], "]"}]]}]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"r", 
       RowBox[{"(", "\[Phi]", ")"}], " ", "for", " ", "En"}], ">", "0"}], ",",
      " ", 
     RowBox[{
      SuperscriptBox["Lz", "2"], ">", 
      RowBox[{"2", 
       RowBox[{"\[Gamma]m", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]1", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      SqrtBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["Lz", "2"], "-", 
         RowBox[{"2", "\[Gamma]", "*", "m"}]}], 
        RowBox[{"2", "m", "*", "En"}]]], 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          SqrtBox[
           RowBox[{
            SuperscriptBox["Lz", "2"], "-", 
            RowBox[{"2", "\[Gamma]", "*", "m"}]}]], "Lz"], 
         RowBox[{"(", 
          RowBox[{"\[Phi]", "-", "\[Phi]0"}], ")"}]}], "]"}], 
       RowBox[{"-", "1"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"r", 
       RowBox[{"(", "\[Phi]", ")"}], " ", "for", " ", "En"}], ">", "0"}], ",",
      " ", 
     RowBox[{
      SuperscriptBox["Lz", "2"], "<", 
      RowBox[{"2", 
       RowBox[{"\[Gamma]m", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]2", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"2", "m", "*", "\[Gamma]"}], "-", 
          SuperscriptBox["Lz", "2"]}], 
         RowBox[{"2", "m", "*", "En"}]]]}], 
      SuperscriptBox[
       RowBox[{"Sinh", "[", 
        RowBox[{
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"2", "m", "*", "\[Gamma]"}], "-", 
            SuperscriptBox["Lz", "2"]}]], "Lz"], 
         RowBox[{"(", 
          RowBox[{"\[Phi]", "-", "\[Phi]0"}], ")"}]}], "]"}], 
       RowBox[{"-", "1"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"r", 
       RowBox[{"(", "\[Phi]", ")"}], " ", "for", " ", "En"}], "<", "0"}], ",",
      " ", 
     RowBox[{
      SuperscriptBox["Lz", "2"], "<", 
      RowBox[{"2", 
       RowBox[{"\[Gamma]m", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]3", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"2", "m", "*", "\[Gamma]"}], "-", 
          SuperscriptBox["Lz", "2"]}], 
         RowBox[{
          RowBox[{"-", "2"}], "m", "*", "En"}]]]}], 
      SuperscriptBox[
       RowBox[{"Cosh", "[", 
        RowBox[{
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"2", "m", "*", "\[Gamma]"}], "-", 
            SuperscriptBox["Lz", "2"]}]], "Lz"], 
         RowBox[{"(", 
          RowBox[{"\[Phi]", "-", "\[Phi]0"}], ")"}]}], "]"}], 
       RowBox[{"-", "1"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"r", 
       RowBox[{"(", "\[Phi]", ")"}], " ", "for", " ", "En"}], "<", "0"}], ",",
      " ", 
     RowBox[{
      SuperscriptBox["Lz", "2"], ">", 
      RowBox[{"2", 
       RowBox[{"\[Gamma]m", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]4", "[", "]"}], ":=", "0"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"r", 
       RowBox[{"(", "\[Phi]", ")"}], " ", "for", " ", "En"}], ">", "0"}], ",",
      " ", 
     RowBox[{
      SuperscriptBox["Lz", "2"], "=", 
      RowBox[{"2", 
       RowBox[{"\[Gamma]m", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]5", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "r0_", ",", "m_", ",", "En_", ",", 
       "Lz_"}], "]"}], ":=", 
     FractionBox["r0", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox[
         RowBox[{"m", "*", "r0", "*", 
          SqrtBox[
           RowBox[{"a", "[", 
            RowBox[{"m", ",", "En"}], "]"}]]}], "Lz"], 
        RowBox[{"(", 
         RowBox[{"\[Phi]", "-", "\[Phi]0"}], ")"}]}]}]]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"r", 
       RowBox[{"(", "\[Phi]", ")"}], " ", "for", " ", "En"}], "=", "0"}], ",",
      " ", 
     RowBox[{
      SuperscriptBox["Lz", "2"], "<", 
      RowBox[{"2", 
       RowBox[{"\[Gamma]m", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]6", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "r0_", ",", "m_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{"r0", "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"m", 
          SqrtBox[
           RowBox[{"-", 
            RowBox[{"b", "[", 
             RowBox[{"m", ",", "\[Gamma]", ",", "Lz"}], "]"}]}]]}], "Lz"], 
        RowBox[{"(", 
         RowBox[{"\[Phi]", "-", "\[Phi]0"}], ")"}]}], "]"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.860148861212469*^9, 3.860148960230051*^9}, {
   3.860149202054676*^9, 3.860149204227507*^9}, {3.860149435249501*^9, 
   3.86014945227598*^9}, {3.860149507447576*^9, 3.860149583212223*^9}, {
   3.860149747564435*^9, 3.860149790432159*^9}, {3.8601499956898327`*^9, 
   3.8601501564829597`*^9}, {3.860150349077704*^9, 3.8601504504212933`*^9}, {
   3.860150883103544*^9, 3.860150892291802*^9}, 3.860150964160686*^9, {
   3.860151217737288*^9, 3.860151229321755*^9}, {3.860151323068121*^9, 
   3.86015133011789*^9}, {3.8601517386844273`*^9, 3.860151973604329*^9}, {
   3.860153044893016*^9, 3.8601531203889008`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"aee873bd-e9bc-4389-89a9-373cc04d62b4"],

Cell[TextData[{
 "Define the vector ",
 Cell[BoxData[
  OverscriptBox["r", "\[RightVector]"]],
  CellChangeTimes->{{3.860149792392692*^9, 3.86014982743736*^9}, {
   3.8601504532846117`*^9, 3.860150475027857*^9}, {3.860150899440537*^9, 
   3.8601509223931723`*^9}},ExpressionUUID->
  "348129e2-2200-4776-b790-158f07e6dc76"],
 "(\[Phi]) that we want to plot. For ",
 Cell[BoxData[
  OverscriptBox["r", "\[RightVector]"]],
  CellChangeTimes->{{3.860149792392692*^9, 3.86014982743736*^9}, {
   3.8601504532846117`*^9, 3.860150475027857*^9}, {3.860150899440537*^9, 
   3.8601509223931723`*^9}},ExpressionUUID->
  "9ea2f5e9-be1a-4397-a2cf-da47be5d5fbd"],
 "(t), we will only plot the magnitude r(t)."
}], "Text",
 CellChangeTimes->{{3.860150912144762*^9, 3.860150946506954*^9}, {
  3.860157089717897*^9, 3.860157107082592*^9}, {3.860175702284115*^9, 
  3.86017570273135*^9}},ExpressionUUID->"81ce9304-b839-4fba-b1a3-\
09747429d71e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    OverscriptBox["r", "\[RightVector]"], 
    RowBox[{
     RowBox[{"(", "\[Phi]", ")"}], "."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]1V", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"r\[Phi]1", "[", 
       RowBox[{
       "\[Phi]", ",", "\[Phi]0", ",", "m", ",", "En", ",", "\[Gamma]", ",", 
        "Lz"}], "]"}], "er"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]2V", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"r\[Phi]2", "[", 
       RowBox[{
       "\[Phi]", ",", "\[Phi]0", ",", "m", ",", "En", ",", "\[Gamma]", ",", 
        "Lz"}], "]"}], "er"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]3V", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"r\[Phi]3", "[", 
       RowBox[{
       "\[Phi]", ",", "\[Phi]0", ",", "m", ",", "En", ",", "\[Gamma]", ",", 
        "Lz"}], "]"}], "er"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]4V", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "m_", ",", "En_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"r\[Phi]4", "[", 
       RowBox[{
       "\[Phi]", ",", "\[Phi]0", ",", "m", ",", "En", ",", "\[Gamma]", ",", 
        "Lz"}], "]"}], "er"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]5V", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "r0_", ",", "m_", ",", "En_", ",", 
       "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"r\[Phi]5", "[", 
       RowBox[{
       "\[Phi]", ",", "\[Phi]0", ",", "r0", ",", "m", ",", "En", ",", "Lz"}], 
       "]"}], "er"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"r\[Phi]6V", "[", 
      RowBox[{
      "\[Phi]_", ",", "\[Phi]0_", ",", "r0_", ",", "m_", ",", "\[Gamma]_", 
       ",", "Lz_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"r\[Phi]6", "[", 
       RowBox[{
       "\[Phi]", ",", "\[Phi]0", ",", "r0", ",", "m", ",", "\[Gamma]", ",", 
        "Lz"}], "]"}], "er"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.860149792392692*^9, 3.86014982743736*^9}, {
  3.8601504532846117`*^9, 3.860150475027857*^9}, {3.860150899440537*^9, 
  3.860150970803585*^9}, {3.860152067064184*^9, 3.8601520914031897`*^9}, {
  3.860152125321472*^9, 3.860152146297509*^9}, {3.8601733366996307`*^9, 
  3.8601733374544563`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"cfcc3ef0-ef29-4af6-ab6f-ad6a27b45401"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Section",
 CellChangeTimes->{{3.860148964221517*^9, 
  3.860148969076405*^9}},ExpressionUUID->"79f1846a-b77d-4c7f-a494-\
e61cce15adf3"],

Cell["The plot(s) for r(t).", "Text",
 CellChangeTimes->{{3.8601735811438513`*^9, 
  3.860173587837235*^9}},ExpressionUUID->"240726d5-7adc-46db-a2f3-\
e4f07c9be043"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Note", " ", "that", " ", "the", " ", "second", " ", "plot", " ", "only", 
    " ", "differs", " ", "from", " ", "the", " ", "first", " ", "by", " ", 
    "a", " ", 
    RowBox[{"sign", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"rt", "[", 
         RowBox[{"t", ",", "t0", ",", "1", ",", "1", ",", "1", ",", "2"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"rt", "[", 
          RowBox[{"t", ",", "t0", ",", "1", ",", "1", ",", "1", ",", "2"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t0", ",", "5"}], "}"}], ",", "0", ",", "10"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.860148970210696*^9, 3.860148976174241*^9}, {
   3.860149157043302*^9, 3.860149241272584*^9}, 3.860149475707492*^9, {
   3.860149588565881*^9, 3.8601496275807734`*^9}, {3.860149836035656*^9, 
   3.860149866070787*^9}, {3.8601502566943083`*^9, 3.8601502817625437`*^9}, {
   3.860152160139442*^9, 3.860152186084958*^9}, {3.860153186026915*^9, 
   3.86015327549179*^9}, {3.860153377702498*^9, 3.8601533860414877`*^9}, {
   3.860173366744574*^9, 3.860173402462278*^9}, {3.8601734888518057`*^9, 
   3.860173490585539*^9}, {3.860173591268916*^9, 
   3.86017359635702*^9}},ExpressionUUID->"706334f8-385a-4e34-9069-\
6cf88fbdc6ce"],

Cell[BoxData[
 FormBox[
  TagBox[
   FormBox[
    StyleBox[
     DynamicModuleBox[{$CellContext`t0$$ = 5, Typeset`show$$ = True, 
      Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
      Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
      "\"untitled\"", Typeset`specs$$ = {{{
         Hold[$CellContext`t0$$], 5}, 0, 10}}, Typeset`size$$ = {
      377., {56., 62.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
      Typeset`skipInitDone$$ = True, $CellContext`t0$2325$$ = 0}, 
      DynamicBox[Manipulate`ManipulateBoxes[
       1, TraditionalForm, "Variables" :> {$CellContext`t0$$ = 5}, 
        "ControllerVariables" :> {
          Hold[$CellContext`t0$$, $CellContext`t0$2325$$, 0]}, 
        "OtherVariables" :> {
         Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
          Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
          Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
          Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> {
          Plot[
           $CellContext`rt[$CellContext`t, $CellContext`t0$$, 1, 1, 1, 
            2], {$CellContext`t, 0, 10}], 
          
          Plot[-$CellContext`rt[$CellContext`t, $CellContext`t0$$, 1, 1, 1, 
             2], {$CellContext`t, 0, 10}]}, 
        "Specifications" :> {{{$CellContext`t0$$, 5}, 0, 10}}, 
        "Options" :> {}, "DefaultOptions" :> {}],
       ImageSizeCache->{422., {100., 107.}},
       SingleEvaluation->True],
      Deinitialization:>None,
      DynamicModuleValues:>{},
      SynchronousInitialization->True,
      UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
      UnsavedVariables:>{Typeset`initDone$$},
      UntrackedVariables:>{Typeset`size$$}], "Manipulate",
     Deployed->True,
     StripOnInput->False],
    TraditionalForm],
   Manipulate`InterpretManipulate[1]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.860149242642988*^9, {3.860149289679682*^9, 3.860149333315802*^9}, {
   3.860149601896311*^9, 3.860149627912348*^9}, 3.860149866419092*^9, {
   3.860150258456637*^9, 3.860150311511765*^9}, {3.8601521762910557`*^9, 
   3.860152186364262*^9}, {3.860153189257333*^9, 3.86015324196914*^9}, 
   3.86015338640932*^9, 3.860173378228825*^9, 3.860173444282724*^9, 
   3.860173492229457*^9, 3.860173559153224*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"f1e5dde4-4768-4209-a38d-0e457d261fbe"]
}, Open  ]],

Cell[TextData[{
 "The plots for ",
 Cell[BoxData[
  OverscriptBox["r", "\[RightVector]"]],
  CellChangeTimes->{{3.86015048427949*^9, 3.860150519048259*^9}, {
   3.860151022321353*^9, 3.860151023491454*^9}, {3.8601510730682898`*^9, 
   3.860151156611341*^9}, {3.8601511956165123`*^9, 3.8601511971795*^9}, {
   3.8601515823437977`*^9, 3.860151608153571*^9}, {3.860152287614748*^9, 
   3.860152440271399*^9}, {3.8601524789959097`*^9, 3.860152581698367*^9}, {
   3.860173404611815*^9, 3.860173431736972*^9}, {3.860173500212047*^9, 
   3.860173542325777*^9}},ExpressionUUID->
  "b95413e2-fd00-4357-8ff9-e3dc00afe65a"],
 "(\[Phi])."
}], "Text",
 CellChangeTimes->{{3.860173601998968*^9, 3.860173627816009*^9}, {
  3.860175684218182*^9, 
  3.860175684641341*^9}},ExpressionUUID->"e49950ab-c696-4c04-a006-\
b72588725695"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Note", " ", "that", " ", "the", " ", "fourth", " ", "plot", " ", 
     "vanishes", " ", "by", " ", "definition", " ", "because", " ", "there", 
     " ", "is", " ", "no", " ", "solution"}], ",", " ", 
    RowBox[{"as", " ", "found", " ", "in", " ", "the", " ", 
     RowBox[{"exercise", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"r\[Phi]1V", "[", 
         RowBox[{
         "\[Phi]", ",", "\[Phi]0", ",", "1", ",", "1", ",", "1", ",", "3"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"r\[Phi]2V", "[", 
         RowBox[{
         "\[Phi]", ",", "\[Phi]0", ",", "1", ",", "1", ",", "1", ",", "1"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"r\[Phi]3V", "[", 
         RowBox[{"\[Phi]", ",", "\[Phi]0", ",", "1", ",", 
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"r\[Phi]4V", "[", 
         RowBox[{"\[Phi]", ",", "\[Phi]0", ",", "1", ",", 
          RowBox[{"-", "1"}], ",", "1", ",", "3"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"r\[Phi]5V", "[", 
         RowBox[{
         "\[Phi]", ",", "\[Phi]0", ",", "r0", ",", "1", ",", "1", ",", "2"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"r\[Phi]6V", "[", 
         RowBox[{
         "\[Phi]", ",", "\[Phi]0", ",", "r0", ",", "1", ",", "1", ",", "1"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Phi]0", ",", 
        RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r0", ",", "5"}], "}"}], ",", "1", ",", "10"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.86015048427949*^9, 3.860150519048259*^9}, {
  3.860151022321353*^9, 3.860151023491454*^9}, {3.8601510730682898`*^9, 
  3.860151156611341*^9}, {3.8601511956165123`*^9, 3.8601511971795*^9}, {
  3.8601515823437977`*^9, 3.860151608153571*^9}, {3.860152287614748*^9, 
  3.860152440271399*^9}, {3.8601524789959097`*^9, 3.860152581698367*^9}, {
  3.860173404611815*^9, 3.860173431736972*^9}, {3.860173500212047*^9, 
  3.860173542325777*^9}, {3.860173630834537*^9, 
  3.8601736314077797`*^9}},ExpressionUUID->"d60e4b3e-556c-45e6-9209-\
39e1ee2b8f82"],

Cell[BoxData[
 FormBox[
  TagBox[
   FormBox[
    StyleBox[
     DynamicModuleBox[{$CellContext`r0$$ = 5, $CellContext`\[Phi]0$$ = 
      Rational[1, 2] Pi, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
      Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ =
       1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
         Hold[$CellContext`\[Phi]0$$], Rational[1, 2] Pi}, 0, 2 Pi}, {{
         Hold[$CellContext`r0$$], 5}, 1, 10}}, Typeset`size$$ = {
      1043., {105., 111.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
      Typeset`skipInitDone$$ = True, $CellContext`\[Phi]0$2565$$ = 
      0, $CellContext`r0$2566$$ = 0}, 
      DynamicBox[Manipulate`ManipulateBoxes[
       1, TraditionalForm, 
        "Variables" :> {$CellContext`r0$$ = 5, $CellContext`\[Phi]0$$ = 
          Rational[1, 2] Pi}, "ControllerVariables" :> {
          Hold[$CellContext`\[Phi]0$$, $CellContext`\[Phi]0$2565$$, 0], 
          Hold[$CellContext`r0$$, $CellContext`r0$2566$$, 0]}, 
        "OtherVariables" :> {
         Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
          Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
          Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
          Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> {
          ParametricPlot[
           $CellContext`r\[Phi]1V[$CellContext`\[Phi], $CellContext`\[Phi]0$$,
             1, 1, 1, 3], {$CellContext`\[Phi], 0, 2 Pi}], 
          ParametricPlot[
           $CellContext`r\[Phi]2V[$CellContext`\[Phi], $CellContext`\[Phi]0$$,
             1, 1, 1, 1], {$CellContext`\[Phi], 0, 2 Pi}], 
          ParametricPlot[
           $CellContext`r\[Phi]3V[$CellContext`\[Phi], $CellContext`\[Phi]0$$,
             1, -1, 1, 1], {$CellContext`\[Phi], 0, 2 Pi}], 
          ParametricPlot[
           $CellContext`r\[Phi]4V[$CellContext`\[Phi], $CellContext`\[Phi]0$$,
             1, -1, 1, 3], {$CellContext`\[Phi], 0, 2 Pi}], 
          ParametricPlot[
           $CellContext`r\[Phi]5V[$CellContext`\[Phi], \
$CellContext`\[Phi]0$$, $CellContext`r0$$, 1, 1, 2], {$CellContext`\[Phi], 0, 
            2 Pi}], 
          ParametricPlot[
           $CellContext`r\[Phi]6V[$CellContext`\[Phi], \
$CellContext`\[Phi]0$$, $CellContext`r0$$, 1, 1, 1], {$CellContext`\[Phi], 0, 
            2 Pi}]}, 
        "Specifications" :> {{{$CellContext`\[Phi]0$$, Rational[1, 2] Pi}, 0, 
           2 Pi}, {{$CellContext`r0$$, 5}, 1, 10}}, "Options" :> {}, 
        "DefaultOptions" :> {}],
       ImageSizeCache->{1088., {163., 170.}},
       SingleEvaluation->True],
      Deinitialization:>None,
      DynamicModuleValues:>{},
      SynchronousInitialization->True,
      UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
      UnsavedVariables:>{Typeset`initDone$$},
      UntrackedVariables:>{Typeset`size$$}], "Manipulate",
     Deployed->True,
     StripOnInput->False],
    TraditionalForm],
   Manipulate`InterpretManipulate[1]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.860150514445672*^9, 3.860150519328958*^9}, 
   3.86015115952045*^9, 3.860151245148239*^9, 3.860151339606021*^9, {
   3.860151608691791*^9, 3.8601516283644667`*^9}, {3.860152289773806*^9, 
   3.8601523404277267`*^9}, {3.8601524312110643`*^9, 3.860152440648246*^9}, 
   3.860152582746982*^9, 3.8601533922642117`*^9, 3.860173444861561*^9, {
   3.8601735034016733`*^9, 3.8601735596946793`*^9}},
 CellLabel->"Out[18]=",ExpressionUUID->"691b18be-1c41-4a78-b00c-f674bc0db564"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 705},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 175, 3, 97, "Title",ExpressionUUID->"f69b802f-5044-468f-a8e1-9bef7a8902d6"],
Cell[758, 27, 176, 3, 40, "Author",ExpressionUUID->"85b37274-23c3-405e-97cd-5b49c1c5812b"],
Cell[937, 32, 152, 3, 42, "Date",ExpressionUUID->"d965cd49-3457-4bc8-8440-fa8d7a341ae9"],
Cell[1092, 37, 432, 8, 34, "Text",ExpressionUUID->"dac38f0b-75c0-4933-b050-b9ced58d4b3a"],
Cell[CellGroupData[{
Cell[1549, 49, 156, 3, 69, "Section",ExpressionUUID->"6132a769-c43c-4e83-a07d-0926f01d53cb"],
Cell[1708, 54, 1683, 38, 101, "Input",ExpressionUUID->"d35989f3-8a4a-4ddf-981a-bfdecfada5d3"],
Cell[3394, 94, 1613, 38, 143, "Input",ExpressionUUID->"d906d344-0a21-4b9c-8407-786ac56c3bfd"],
Cell[5010, 134, 1940, 57, 172, "Text",ExpressionUUID->"70e003b5-3a8c-4787-8a67-a287fe8028f0"],
Cell[6953, 193, 7065, 213, 680, "Input",ExpressionUUID->"aee873bd-e9bc-4389-89a9-373cc04d62b4"],
Cell[14021, 408, 926, 20, 34, "Text",ExpressionUUID->"81ce9304-b839-4fba-b1a3-09747429d71e"],
Cell[14950, 430, 2895, 80, 169, "Input",ExpressionUUID->"cfcc3ef0-ef29-4af6-ab6f-ad6a27b45401"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17882, 515, 150, 3, 69, "Section",ExpressionUUID->"79f1846a-b77d-4c7f-a494-e61cce15adf3"],
Cell[18035, 520, 165, 3, 34, "Text",ExpressionUUID->"240726d5-7adc-46db-a2f3-e4f07c9be043"],
Cell[CellGroupData[{
Cell[18225, 527, 1712, 41, 63, "Input",ExpressionUUID->"706334f8-385a-4e34-9069-6cf88fbdc6ce"],
Cell[19940, 570, 2395, 48, 233, "Output",ExpressionUUID->"f1e5dde4-4768-4209-a38d-0e457d261fbe"]
}, Open  ]],
Cell[22350, 621, 813, 17, 34, "Text",ExpressionUUID->"e49950ab-c696-4c04-a006-b72588725695"],
Cell[CellGroupData[{
Cell[23188, 642, 3390, 85, 126, "Input",ExpressionUUID->"d60e4b3e-556c-45e6-9209-39e1ee2b8f82"],
Cell[26581, 729, 3502, 66, 359, "Output",ExpressionUUID->"691b18be-1c41-4a78-b00c-f674bc0db564"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

